#ifndef __MODELDEF_H
#define __MODELDEF_H

#include "config.h"

/* define the default maximum number of quad-site-exchanges */
#ifndef Nq
#define Nq (NN*4)
#endif

extern double pos[NN][3];               /* site-position = (x,y,z)      */
extern double edg[3][3];                /* edge vectors default=(0,0,0) */
extern int  iw[Nw][2];                  /* array bonds          */
extern int  iq[Nq][4];                  /* array four-site-terms (quad?) */
extern int nn,nw,nq;              /* number of spins and bonds < NN,Nw,Nq */
extern int nu,nd;                       /* number up-/down-spins        */
/* ww-indexed float parameters for wt[],wj[],wu[],we[],wu2,wj2[], etc. */
#define MaxPara 128                     /* max. 8bit=1char      */
extern char numpara;                    /* number of parameters < 128   */
extern double para[MaxPara];            /* Float-Parameters     */


/* index to float parameters para[], moved to tww since v2.20 */
struct tww {                            /* parameter of the Hamiltonien */
 /* one site parameters */
 int wu[NN];                      /* model parameter coulomb  U(i) */
 int we[NN];                      /* model parameter site-energy e(i) */
 int wf[NN];			  /* external z-field h(i) per site */
 int wd[NN];			  /* single ion anisotropy D(i) */
 /* two site parameters */
 int    w[Nw];                    /* phase-angle (boundary=TBC) */
 double co[Nw],si[Nw];            /* cos(para[w]),sin(para[w])    */
 int    ex[Nw];                   /* 1 bound ok, -1 size exchange */
 int wt[Nw];                      /* model parameter hopping  t(i,j) */
 int wj[Nw];                      /* model parameter exchange J(i,j) */
 int wv[Nw];                      /* two-site coulomb  V(i,j) ??? */
 int wh[Nw];                      /* hole-hole repulsion */
 /* four site parameters */
 int wq[Nq];                      /* four-site exchange P(i,i+1)+P^-1(i,i+1) */
};      

extern struct tww ww;  

#ifndef IFww
#ifdef CONFIG_TBC			/* see config.h */
#define IFww(x)     x
#else
#define IFww(x)
#endif
#endif

#if (0 IFww(+1)) && !defined(CONFIG_TBC)
#error please use CONFIG_TBC instead of IFww in config.h 
#endif

int initvars();	/* function definition */
int outmodel();

#endif
